[mutter] background-group: Subclass ClutterActor, not ClutterGroup



commit 0bb8d29be4693b9b0de7b957d6fc6d792c9d24d2
Author: Jasper St. Pierre <jstpierre mecheye net>
Date:   Thu Mar 14 17:20:54 2013 -0400

    background-group: Subclass ClutterActor, not ClutterGroup
    
    We use the new Clutter Actor API in the shell, so we really
    shouldn't be using ClutterGroup.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=695881

 src/compositor/meta-background-group.c |    2 +-
 src/meta/meta-background-group.h       |    6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/compositor/meta-background-group.c b/src/compositor/meta-background-group.c
index 52e8372..5bf6d4a 100644
--- a/src/compositor/meta-background-group.c
+++ b/src/compositor/meta-background-group.c
@@ -7,7 +7,7 @@
 #include "meta-background-actor-private.h"
 #include "meta-background-group-private.h"
 
-G_DEFINE_TYPE (MetaBackgroundGroup, meta_background_group, CLUTTER_TYPE_GROUP);
+G_DEFINE_TYPE (MetaBackgroundGroup, meta_background_group, CLUTTER_TYPE_ACTOR);
 
 struct _MetaBackgroundGroupPrivate
 {
diff --git a/src/meta/meta-background-group.h b/src/meta/meta-background-group.h
index cddc1c5..8c1cb4a 100644
--- a/src/meta/meta-background-group.h
+++ b/src/meta/meta-background-group.h
@@ -8,7 +8,7 @@
 /**
  * MetaBackgroundGroup:
  *
  * This class is a subclass of ClutterGroup with special handling for
  * MetaBackgroundActor when painting the group. It makes sure to only
  * draw the parts of the backgrounds not occluded by opaque windows.
  *
@@ -29,12 +29,12 @@ typedef struct _MetaBackgroundGroupPrivate MetaBackgroundGroupPrivate;
 
 struct _MetaBackgroundGroupClass
 {
-  ClutterGroupClass parent_class;
+  ClutterActorClass parent_class;
 };
 
 struct _MetaBackgroundGroup
 {
-  ClutterGroup parent;
+  ClutterActor parent;
 
   MetaBackgroundGroupPrivate *priv;
 };
@@ -8,7 +8,7 @@
  * MetaBackgroundGroup:
  *
- * This class is a subclass of ClutterGroup with special handling for
+ * This class is a subclass of ClutterActor with special handling for
  * MetaBackgroundActor when painting the group. It makes sure to only
  * draw the parts of the backgrounds not occluded by opaque windows.


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]